@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 """cyclograph.py """
 
-# Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013 Federico Brega, Pierluigi Villani
+# Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013, 2014 Federico Brega, Pierluigi Villani
 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -221,11 +221,19 @@ class Cyclograph():
         else:
             if slopefile != None:
                 max_num_cps = len(slopefile)
-                (seltype, num) = glal.gui.numcpsdlg(max_num_cps, slopefile.max_dist(), filetype)
-                if not slopefile.hasAltitudes:
-                    self.import_altitudes(num, seltype, slopefile, slope_num)
+                (seltype, num, start_dist, end_dist) = glal.gui.numcpsdlg(max_num_cps,
+                                                    slopefile.min_dist(),
+                                                    slopefile.max_dist(),
+                                                    filetype)
+                if (seltype == -1):
+                    nbook = None
+                    self.slopelist.del_slope(slope_num)
+                    self.notebook.remove_page(slope_num)
                     return
-                statusok = slopefile.newSlope(self.slopelist, slope_num, num, seltype)
+                if not slopefile.hasAltitudes:
+                    self.import_altitudes(num, seltype, slopefile, start_dist, end_dist, slope_num)
+                    return
+                statusok = slopefile.newSlope(self.slopelist, slope_num, num, start_dist, end_dist, seltype)
                 #listcoords = self.slopelist.get_coords(slope_num)
                 #print(listcoords)
             else:
@@ -254,7 +262,7 @@ class Cyclograph():
         def savefunc(handler, mode):
             """Save as kml current create_kml selected route"""
             content = handler.read()
-            if mode != 'DRAW':
+            if mode != 'DRAW' and mode != 'YOURS':
                 content = iofile.gpxtokml(content)
             filepath = glal.FileDialog(None, _("kml name"), "", "",
                    [("Keyhole Markup Language (*.kml)","*.kml")], glal.FD_SAVE)
@@ -289,6 +297,8 @@ class Cyclograph():
             gpxcontent = gpxcontent.replace("rte", "trk")
             gpxcontent = gpxcontent.replace("rtept", "trkseg")
             kmlcontent = iofile.gpxtokml(gpxcontent)
+        elif create.mode == 'YOURS':
+            kmlcontent = create.handler.read()
         kmlfile = iofile.load_kmlfile(kmlcontent)
         if kmlfile == None:
             glal.addstatusbartext(self.mygui, _("Error on loading slope"))
@@ -301,19 +311,22 @@ class Cyclograph():
         self.slopecounter = self.slopecounter + 1
         self.tabupdate(slope_num, '*')
 
-        self.import_altitudes(numcps, 0, kmlfile, slope_num)
+        self.import_altitudes(numcps, 0, kmlfile,
+                                         kmlfile.min_dist,
+                                         kmlfile.max_dist,
+                                         slope_num)
         create.destroy()
 
-    def import_altitudes(self, num, seltype, slopefile, slope_num):
-        """ Start the import kml process in cycloGraph"""
+    def import_altitudes(self, num, seltype, slopefile, start_dist, end_dist, slope_num):
+        """ Start the import kml process in CycloGraph"""
         #TODO: check for internet connection
         self.slopenumber_kml = slope_num
-        slopefile.getCoords(self.slopelist, slope_num)
+        slopefile.getCoords(self.slopelist, slope_num, start_dist, end_dist)
         self.pdlg = glal.ProgressDialog()
         refresh_time = 30 #FIXME: is the measure unit milliseconds?
         self.timer = glal.Timer(refresh_time, self.on_altitude_importing)
         self.queue = Queue.Queue()
-        self.prsrthrd = altitude_downloader.ImporterThread(self.queue, slopefile, num, seltype)
+        self.prsrthrd = altitude_downloader.ImporterThread(self.queue, slopefile, num, start_dist, end_dist, seltype)
         self.prsrthrd.daemon = True
         #start thread and timer
         self.prsrthrd.start()
@@ -471,10 +484,6 @@ class Cyclograph():
         """Set kml server3"""
         self.config.set("kml", "server", "usgs.net")
         altitude_downloader.choose_service("usgs.net")
-    def ser4(self, event=None):
-        """Set kml server4"""
-        self.config.set("kml", "server", "google elevation")
-        altitude_downloader.choose_service("google elevation")
 
     def savepref(self, event=None):
         """Save preferences.
@@ -842,28 +851,29 @@ def getconfig(config):
 
 def usage():
     """ Print usage on standard error"""
-    sys.stderr.write( "usage: %s {-q|-g|-G|-f}\n"% sys.argv[0])
-    sys.stderr.write("\t--qt --gtk --gtk3 or --file=*.cgx file for cli\n")
+    sys.stderr.write( "usage: %s {-q|-G|-f}\n"% sys.argv[0])
+    sys.stderr.write("\t--qt --gtk3 or --file=*.cgx file for cli\n")
 
 def opt_parser(argv):
     """ Parse console input"""
     domain = gettext.textdomain(None)
     gettext.textdomain("help")
     parser = OptionParser(usage=(
-"""usage: %s {-q|-g|-G|-f}
-filename\t--qt --gtk --gtk3 or --file=FILENAME for cli""" % argv[0]),
+"""usage: %s {-q|-G|-f}
+filename\t--qt --gtk3 or --file=FILENAME for cli""" % argv[0]),
                                 version="%prog "+VERSION)
     #parser = OptionParser(version="%prog "+VERSION)
     parser.set_defaults(filename="")
     parser.set_defaults(gui="cli")
-    parser.add_option("-g", "--gtk", help="gtk graphical user interface",
-                      action="store_const", dest="gui", const="gtk")
     parser.add_option("-G", "--gtk3", help="gtk3 graphical user interface",
                       action="store_const", dest="gui", const="gtk3")
     parser.add_option("-q", "--qt", help="qt graphical user interface",
                       action="store_const", dest="gui", const="qt")
     parser.add_option("-f", "--file", dest="filename",
                       help="open cgx, csv, gpx, tcx, sal, crp or cyclomaniac file", metavar="FILE")
+    parser.add_option("-s", "--size", dest="size",
+                      action="store", type="string",
+                      help="output size widthxheight")
     parser.add_option("-l", "--list", dest="_list",
                       action="store_true",
                       help="list available themes and exit")
@@ -901,14 +911,6 @@ def main_qt():
         controller.open_slope(filepath=options.filename)
     sys.exit(app.exec_())
 
-def main_gtk():
-    """Main application for gtk interface"""
-    controller = Cyclograph()
-    options = opt_parser(sys.argv)
-    if options.filename:
-        controller.open_slope(filepath=options.filename)
-    glal.initapp()
-
 def main_gtk3():
     """Main application for gtk3 interface"""
     controller = Cyclograph()
@@ -942,7 +944,20 @@ def main_cli():
     settings = getconfig(config)
     if opt.theme:
         settings['theme'] = opt.theme #FIXME: this should work also with GUIs
-    devc.init_draw_surf((settings['width'], settings['height']), settings['3d'])
+    size_w = settings['width']
+    size_h = settings['height']
+    if opt.size:
+        size_el = opt.size.split('x')
+        if len(size_el) == 2:
+            try:
+                el_w = int(size_el[0])
+                el_h = int(size_el[1])
+                if (el_w > 0) and (el_h > 0):
+                    size_w = el_w
+                    size_h = el_h
+            except ValueError:
+                print(('ValueError reading size "%s"' % opt.size), file=sys.stderr)
+    devc.init_draw_surf((size_w, size_h), settings['3d'])
     myslope.paint(settings, devc)
     devc.end_draw()
     #img.savetofile(filecsv[:-4]+".svg")
