@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 """gtk3.gui.py"""
 
-# Copyright (C) 2011, 2012, 2013 Pierluigi Villani
+# Copyright (C) 2011, 2012, 2013, 2014 Pierluigi Villani
 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -292,7 +292,7 @@ def onabout(event):
     about = Gtk.AboutDialog()
     about.set_program_name("CycloGraph")
     about.set_version(VERSION)
-    about.set_copyright("Copyright (C) 2008-2013 Federico Brega, Pierluigi Villani")
+    about.set_copyright("Copyright (C) 2008-2014 Federico Brega, Pierluigi Villani")
     about.set_authors(("Federico Brega", "Pierluigi Villani"))
     about.set_license("""
 CycloGraph is free software: you can redistribute it and/or modify
@@ -320,7 +320,7 @@ class Page(Gtk.ScrolledWindow):
         self.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
         self.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
 
-        self.store = Gtk.ListStore(str, str, str)
+        self.store = Gtk.ListStore(int, str, str, str)
         self.mylistctrl = Gtk.TreeView.new_with_model(self.store)
         self.mylistctrl.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
         #rows of alternate color
@@ -334,29 +334,42 @@ class Page(Gtk.ScrolledWindow):
         self.closebox = None
 
         rendererText = Gtk.CellRendererText()
-        column = Gtk.TreeViewColumn(_(u"Distance [km]"), rendererText, text=0)
+        column = Gtk.TreeViewColumn(u"#", rendererText, text=0)
         column.set_sort_column_id(0)
         self.mylistctrl.append_column(column)
 
         rendererText = Gtk.CellRendererText()
-        column = Gtk.TreeViewColumn(_(u"Altitude [m]"), rendererText, text=1)
+        column = Gtk.TreeViewColumn(_(u"Distance [km]"), rendererText, text=1)
         column.set_sort_column_id(1)
         self.mylistctrl.append_column(column)
 
         rendererText = Gtk.CellRendererText()
-        column = Gtk.TreeViewColumn(_(u"Name"), rendererText, text=2)
+        column = Gtk.TreeViewColumn(_(u"Altitude [m]"), rendererText, text=2)
         column.set_sort_column_id(2)
         self.mylistctrl.append_column(column)
 
+        rendererText = Gtk.CellRendererText()
+        column = Gtk.TreeViewColumn(_(u"Name"), rendererText, text=3)
+        column.set_sort_column_id(3)
+        self.mylistctrl.append_column(column)
+
         self.mylistctrl.set_headers_clickable(False) #disable column sort
 
     def insert_row(self, row_num, chkpnt):
         """Insert item to this page at position row_num"""
-        self.store.insert(row_num, [unicode(chkpnt[0]),
+        self.store.insert(row_num, [row_num, unicode(chkpnt[0]),
                                     unicode(chkpnt[1]), chkpnt[2]])
+        treeiter = self.store.get_iter(path = (row_num,))
+        while treeiter != None:
+            self.store[treeiter][0] = self.store[treeiter][0] + 1
+            treeiter = self.store.iter_next(treeiter)
     def delete_row(self, row_num):
         """Removes row at position row_num in this page."""
         itera = self.store.get_iter(path = (row_num,))
+        treeiter = self.store.iter_next(itera)
+        while treeiter != None:
+            self.store[treeiter][0] = self.store[treeiter][0] - 1
+            treeiter = self.store.iter_next(treeiter)
         self.store.remove(itera)
     def get_sel_row(self):
         """Gives the row number that is selected."""
@@ -786,14 +799,11 @@ class Preferences(Gtk.Dialog):
         self.serv.append_text('geonames.org')
         self.serv.append_text('earthtools.org')
         self.serv.append_text('usgs.net')
-        self.serv.append_text('google elevation')
         self.serv.set_active(0)
         if pref['serv'] == 'usgs.net':
             self.serv.set_active(2)
         elif pref['serv'] == 'earthtools.org':
             self.serv.set_active(1)
-        elif pref['serv'] == 'google elevation':
-            self.serv.set_active(3)
         vbox.pack_start(self.serv, False, False, 0)
 
         label = Gtk.Label(label="<b>"+_(u"Latest version")+"</b>")
@@ -925,8 +935,8 @@ class Preferences(Gtk.Dialog):
         notebook.show_all()
 
         bbox = Gtk.HBox()
-        button_k = Gtk.Button(None, Gtk.STOCK_OK)
-        button_c = Gtk.Button(None, Gtk.STOCK_CANCEL)
+        button_k = Gtk.Button(stock=Gtk.STOCK_OK)
+        button_c = Gtk.Button(stock=Gtk.STOCK_CANCEL)
         button_d = Gtk.Button(_(u"Restore Default"))
         bbox.pack_end(button_k, False, False, 5)
         bbox.pack_end(button_c, False, False, 5)
@@ -960,7 +970,7 @@ class Preferences(Gtk.Dialog):
         self.olines.set_active(bool(self.default['orizzontal lines']))
         self.effect3d.set_active(bool(self.default['effect-3d']))
         self.showinfo.set_active(bool(self.default['slopeinfo']))
-        self.vcheck.set_active(bool(self.default['vcheck']))
+        self.vcheck.set_active(bool(self.default['latestVersionCheck']))
         self.res.set_active(0)
         if self.default['width'] == 1600:
             self.res.set_active(3)
@@ -979,21 +989,19 @@ class Preferences(Gtk.Dialog):
             self.serv.set_active(2)
         elif self.default['server'] == 'earthtools.org':
             self.serv.set_active(1)
-        elif self.default['server'] == 'google elevation':
-            self.serv.set_active(3)
-        self.fdesc = Gtk.Button(self.default['font-des 1']+' | '+self.default['font-dim 1'])
+        self.fdesc.set_label(self.default['font-des 1']+' | '+self.default['font-dim 1'])
         self.fdesc.desc = {
                                "des" : self.default['font-des 1'],
                                "typ" : self.default['font-typ 1'],
                                "dim" : self.default['font-dim 1']
                            }
-        self.fgrad = Gtk.Button(self.default['font-des g']+' | '+self.default['font-dim g'])
+        self.fgrad.set_label(self.default['font-des g']+' | '+self.default['font-dim g'])
         self.fgrad.desc = {
                                "des" : self.default['font-des g'],
                                "typ" : self.default['font-typ g'],
                                "dim" : self.default['font-dim g']
                            }
-        self.ftitle = Gtk.Button(self.default['font-des t']+' | '+self.default['font-dim t'])
+        self.ftitle.set_label(self.default['font-des t']+' | '+self.default['font-dim t'])
         self.ftitle.desc = {
                                "des" : self.default['font-des t'],
                                "typ" : self.default['font-typ t'],
@@ -1096,9 +1104,13 @@ class Map(Gtk.Dialog):
         obox.pack_start(swframe, True, True, 0)
 
         bbox = Gtk.HBox()
-        button_s = Gtk.Button(None, Gtk.STOCK_SAVE)
+        button_s = Gtk.Button(stock=Gtk.STOCK_SAVE)
+        button_c = Gtk.Button(stock=Gtk.STOCK_CANCEL)
+        
         bbox.pack_end(button_s, False, False, 5)
+        bbox.pack_end(button_c, False, False, 5)
         button_s.connect("clicked", self.onsave)
+        button_c.connect("clicked", self.cancel)
 
         box = Gtk.VBox()
         box.pack_start(obox, True, True, 0)
@@ -1123,6 +1135,10 @@ class Map(Gtk.Dialog):
         """ Save call"""
         self.savefnct(self)
 
+    def cancel(self, event):
+        """ Cancel Map dialog"""
+        self.destroy()
+
     def saveimage(self, filepath):
         """ Save map image"""
         winw, winh = self.get_size()
@@ -1151,6 +1167,7 @@ class Create_kml(Gtk.Dialog):
     """Create kml routes"""
     MODE = {_(u'Open Route Service') : 'ORS',
             _(u'OSRM') : 'OSRM',
+            _(u'yournavigation') : 'YOURS',
             _(u"Draw on the map") : 'DRAW'}
     def __init__(self, parent, downloadfunc, savefunc):
         Gtk.Window.__init__(self)
@@ -1174,6 +1191,7 @@ class Create_kml(Gtk.Dialog):
         store = Gtk.ListStore(str)
         store.append([_(u'Open Route Service')])
         store.append([_(u'OSRM')])
+        store.append([_(u'yournavigation')])
         store.append([_(u'Draw on the map')])
 
         treeview = Gtk.TreeView.new_with_model(store)
@@ -1198,9 +1216,9 @@ class Create_kml(Gtk.Dialog):
         obox.pack_start(swframe, True, True, 5)
 
         bbox = Gtk.HBox()
-        button_k = Gtk.Button(None, Gtk.STOCK_OK)
-        button_s = Gtk.Button(None, Gtk.STOCK_SAVE)
-        button_c = Gtk.Button(None, Gtk.STOCK_CANCEL)
+        button_k = Gtk.Button(stock=Gtk.STOCK_OK)
+        button_s = Gtk.Button(stock=Gtk.STOCK_SAVE)
+        button_c = Gtk.Button(stock=Gtk.STOCK_CANCEL)
         bbox.pack_end(button_k, False, False, 5)
         bbox.pack_end(button_s, False, False, 5)
         bbox.pack_end(button_c, False, False, 5)
@@ -1222,6 +1240,8 @@ class Create_kml(Gtk.Dialog):
             self.view.open("http://openrouteservice.org/")
         elif self.mode == 'OSRM':
             self.view.open("http://map.project-osrm.org/")
+        elif self.mode == 'YOURS':
+            self.view.open('http://yournavigation.org/')
         elif self.mode == 'DRAW':
             HTML_DRAW = ""
             try:
@@ -1266,10 +1286,21 @@ class Create_kml(Gtk.Dialog):
         self.view.execute_script("oldtitle=document.title;document.title=document.getElementsByClassName('text-link')[1].getAttribute('onclick')")
         gpxcontent = unicode(self.view.get_main_frame().get_title())
         url = gpxcontent.split('\'')
-        print(url)
         self.view.execute_script('document.title=oldtitle;')
         return self.downloadfunc(url[1])
 
+    def get_yours(self):
+        """ Returns kml content from YOURS service"""
+        self.view.execute_script("oldtitle=document.title;document.title=document.getElementById('feature_info').innerHTML")
+        elemtext = unicode(self.view.get_main_frame().get_title())
+        text = elemtext.split('href="http://yournavigation.org/?')
+        turl = "http://www.yournavigation.org/api/1.0/gosmore.php?format=kml&"
+        if len(text) > 1:
+            turl += text[1].split("\">")[0]
+            turl = turl.replace("&amp;", "&")
+        self.view.execute_script('document.title=oldtitle;')
+        return self.downloadfunc(turl)
+
     def get_draw(self):
         """ Returns kml content from DRAW mode"""
         self.view.execute_script("oldtitle=document.title;document.title=createKml()")
@@ -1283,6 +1314,8 @@ class Create_kml(Gtk.Dialog):
             self.handler = self.get_ors()
         elif self.mode == 'OSRM':
             self.handler = self.get_osrm()
+        elif self.mode == 'YOURS':
+            self.handler = self.get_yours() 
         elif self.mode == 'DRAW':
             self.handler = self.get_draw()
 
@@ -1414,7 +1447,7 @@ class ProgressDialog(Gtk.Dialog):
 
 class NumcpsDialog(Gtk.Dialog):
     """ask cps number you want to import"""
-    def __init__(self, max_num_cps, max_length, file_ext):
+    def __init__(self, max_num_cps, start_dist, max_dist, file_ext):
         GObject.GObject.__init__(self)
 
         self.set_title(_(u"number of checkpoints"))
@@ -1454,11 +1487,41 @@ class NumcpsDialog(Gtk.Dialog):
 
         hboxr.pack_start(vboxr, False, False, 30)
 
+        hbx = Gtk.HBox()
+        self.tick = 0.1
+        self.startdist = start_dist
+        self.maxdist = max_dist
+
+        self.bstartdist = Gtk.SpinButton()
+        self.bstartdist.set_range(start_dist, max_dist)
+        self.bstartdist.set_value(start_dist)
+        self.bstartdist.set_increments(self.tick, 1)
+        self.bstartdist.set_numeric(True)
+        self.bstartdist.set_digits(3)
+        self.bstartdist.connect("value_changed", self.changed_dist)
+
+        self.benddist = Gtk.SpinButton()        
+        self.benddist.set_range(start_dist, max_dist)
+        self.benddist.set_value(max_dist)
+        self.benddist.set_increments(self.tick, 1)
+        self.benddist.set_numeric(True)
+        self.benddist.set_digits(3)
+        self.benddist.connect("value_changed", self.changed_dist)
+
+        hbx.pack_start(Gtk.Label(label=_(u"Start")), False, False, 10)
+        hbx.pack_start(self.bstartdist, False, False, 10)
+        hbx.pack_start(Gtk.Label(label=_(u"End")), False, False, 10)
+        hbx.pack_start(self.benddist, False, False, 10)
+
         bbox = Gtk.HBox()
+        button_c = Gtk.Button(_(u"Cancel"))
         button_n = Gtk.Button(_(u"Next"))
         bbox.pack_end(button_n, False, False, 5)
+        bbox.pack_end(button_c, False, False, 5)
         button_n.connect("clicked", self.next_clicked)
+        button_c.connect("clicked", self.destroy)
         vbox_1.pack_end(bbox, False, False, 10)
+        vbox_1.pack_end(hbx, False, False, 5)
         vbox_1.pack_end(hboxr, False, False, 5)
 
         frame.add(vbox_1)
@@ -1492,16 +1555,29 @@ class NumcpsDialog(Gtk.Dialog):
 
         frame = Gtk.Frame()
         boxdist = Gtk.VBox()
-        label = Gtk.Label(label=_(u"The %s file contains a route of %d Km.\nChoose what range you want between points.") % (file_ext, max_length))
+        hboxdist = Gtk.HBox()
+        selrange = self.benddist.get_value() - self.bstartdist.get_value()
+        label = Gtk.Label(label=_(u"The %s file contains a route of %.3f Km.\nChoose what range you want between points.") % (file_ext, selrange))
+        self.spingpxdist = Gtk.SpinButton()        
+        self.spingpxdist.set_range(0, selrange)
+        self.spingpxdist.set_value(0)
+        self.spingpxdist.set_increments(self.tick, 1)
+        self.spingpxdist.set_numeric(True)
+        self.spingpxdist.set_digits(3)
+        self.spingpxdist.connect("value_changed", self.changed_rangedist)
         self.gpxdist = Gtk.HScale()
-        self.gpxdist.set_range(0, int(max_length))
-        self.gpxdist.set_increments(1, 1)
-        self.gpxdist.set_digits(0)
+        self.gpxdist.set_range(0, selrange)
+        self.gpxdist.set_increments(self.tick, 1)
+        self.gpxdist.set_digits(3)
         self.gpxdist.set_size_request(160, 38)
         self.gpxdist.set_value(0)
+        self.gpxdist.set_draw_value(False)
+        self.gpxdist.connect("value_changed", self.changed_rangescaledist)
 
+        hboxdist.pack_start(self.spingpxdist, False, False, 10)
+        hboxdist.pack_start(self.gpxdist, False, False, 5)
         boxdist.pack_start(label, False, False, 5)
-        boxdist.pack_start(self.gpxdist, False, False, 5)
+        boxdist.pack_start(hboxdist, False, False, 15)
 
         bbox = Gtk.HBox()
         button_n = Gtk.Button(_(u"Finish"))
@@ -1524,6 +1600,19 @@ class NumcpsDialog(Gtk.Dialog):
 
         self.show_all()
 
+    def changed_dist(self, event):
+        "Changed dist"
+        self.bstartdist.set_range(self.startdist, self.benddist.get_value() - self.tick)
+        self.benddist.set_range(self.bstartdist.get_value() + self.tick, self.maxdist)
+
+    def changed_rangedist(self, event):
+        "Changed range dist"
+        self.gpxdist.set_value(self.spingpxdist.get_value())
+
+    def changed_rangescaledist(self, event):
+        "Changed range dist"
+        self.spingpxdist.set_value(self.gpxdist.get_value())
+
     def next_clicked(self, event):
         "Show next page"
         if self.notebook.get_current_page() == 0:
@@ -1533,6 +1622,11 @@ class NumcpsDialog(Gtk.Dialog):
                 self.notebook.set_current_page(1)
                 self.notebook.show_all()
             elif self.button3.get_active():
+                selrange = self.benddist.get_value() - self.bstartdist.get_value()
+                self.spingpxdist.set_range(0, selrange)
+                self.spingpxdist.set_value(0)
+                self.gpxdist.set_range(0, selrange)
+                self.gpxdist.set_value(0)
                 self.notebook.set_current_page(2)
                 self.notebook.show_all()
             elif self.button4.get_active():
@@ -1587,26 +1681,34 @@ def geterrnocp(parent):
     mdlg.run()
     mdlg.destroy()
 
-def numcpsdlg(max_num_cps, max_length, file_ext):
+def numcpsdlg(max_num_cps, start_dist, max_dist, file_ext):
     """ask what number of cps in a gpx or tcx files have to be imported"""
-    dlg = NumcpsDialog(max_num_cps, max_length, file_ext)
+    dlg = NumcpsDialog(max_num_cps, start_dist, max_dist, file_ext)
     response = dlg.run()
     if response == False:
-        return (-1, 0)
+        return (-1, 0, start_dist, max_dist)
     if dlg.button1.get_active():
+        valstart = dlg.bstartdist.get_value()
+        valend = dlg.benddist.get_value()
         dlg.destroy()
-        return (0, -1)
+        return (0, -1, valstart, valend)
     elif dlg.button2.get_active():
         val = dlg.gpxnum.get_value()
+        valstart = dlg.bstartdist.get_value()
+        valend = dlg.benddist.get_value()
         dlg.destroy()
-        return (0, int(val))
+        return (0, int(val), valstart, valend)
     elif dlg.button3.get_active():
         val = dlg.gpxdist.get_value()
+        valstart = dlg.bstartdist.get_value()
+        valend = dlg.benddist.get_value()
         dlg.destroy()
-        return (1, int(val))
+        return (1, val, valstart, valend)
     elif dlg.button4.get_active():
+        valstart = dlg.bstartdist.get_value()
+        valend = dlg.benddist.get_value()
         dlg.destroy()
-        return (0, max_num_cps)
+        return (0, max_num_cps, valstart, valend)
 
 def assistant_end(parent, value):
     parent.Close()
