@@ -1,7 +1,7 @@
-﻿# -*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 """iofile.py"""
 
-# Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013 Federico Brega, Pierluigi Villani
+# Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013, 2014 Federico Brega, Pierluigi Villani
 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -124,28 +124,28 @@ def open_file(filename, slopelist, slopenum, extension=''):
     elif extension == 'gpx':
         try:
             gpxfile = load_gpxfile(filename)
-            gpxfile.newSlope(slopelist, slopenum, -1)
+            gpxfile.newSlope(slopelist, slopenum, -1, gpxfile.min_dist(), gpxfile.max_dist())
             statusok = True
         except IOError:
             statusok = False
     elif extension == 'kml':
         try:
             kmlfile = load_kmlfile(filename)
-            kmlfile.newSlope(slopelist, slopenum, -1)
+            kmlfile.newSlope(slopelist, slopenum, -1, kmlfile.min_dist(), kmlfile.max_dist())
             statusok = True
         except IOError:
             statusok = False
     elif extension == 'fitlog':
         try:
             fitlogfile = load_fitlogfile(filename)
-            fitlogfile.newSlope(slopelist, slopenum, -1)
+            fitlogfile.newSlope(slopelist, slopenum, -1, fitlogfile.min_dist(), fitlogfile.max_dist())
             statusok = True
         except IOError:
             statusok = False
     elif extension == 'tcx':
         try:
             tcxfile = load_tcxfile(filename)
-            tcxfile.newSlope(slopelist, slopenum, -1)
+            tcxfile.newSlope(slopelist, slopenum, -1, tcxfile.min_dist(), tcxfile.max_dist())
             statusok = True
         except IOError:
             statusok = False
@@ -416,6 +416,7 @@ def load_kmlfile(xmlfile):
             node = coords.childNodes[0]
 
             data = node.data.strip(' \n')
+            data = data.replace('\n', ' ')
             coordlist += [el.split(',')[:2] for el in data.split(' ')]
 
         #if LineString is not present try gx:coord (KML 2.2 ext)
@@ -639,45 +640,90 @@ class SlopeFile:
     def __init__(self, cps):
         """Load a track file"""
         self.cps = cps
+        self.cpToLoad = []
         self.hasAltitudes = False
+    def min_dist(self):
+        """ Minimum distance of the track """
+        return self.cps[0][0]
     def max_dist(self):
         """ Maximum distance of the track """
         return self.cps[-1][0]
     def __len__(self):
         """ Number of points of the track """
         return len(self.cps)
-    def newSlope(self, slopelist, slopenum, num, seltype=0):
+    def newSlope(self, slopelist, slopenum, num, start_dist, end_dist, seltype=0):
         """ Create a new slope in the slopelist"""
+        self.setcpToLoad(num, start_dist, end_dist, seltype)
+        self.getCoords(slopelist, slopenum, start_dist, end_dist)
+        for icp in self.cpToLoad:
+            (dist, alt, name, lat, lng)= self.cps[icp]
+            normadist = dist - float(start_dist)
+            slopelist.add_cp(slopenum, normadist, alt, name)
+        return True
+    def setcpToLoad(self, num, start_dist, end_dist, seltype):
+        """ Set cp index to load"""
+        self.cpToLoad = []
+
+        startindex = 0
+        endindex = len(self.cps)
+        lencps = len(self.cps)
+
+        for i in range(lencps):
+            if self.cps[i][0] >= start_dist:
+                startindex = i
+                break
+        for i in range(lencps):
+            if self.cps[lencps-i-1][0] <= end_dist:
+                endindex = lencps - i
+                break
+
+        #print(startindex)
+        #print(endindex)
+
         if seltype == 0:#using the given number of check points in num
             max_dist = self.max_dist()
             next_cp = 0.0
+
             if num == -1:
                 N = 30
             elif num == 0:
-                N = len(self.cps)
+                N = endindex - startindex
             else:
                 N = num
-            for i in range(len(self.cps)):
-                (dist, alt, name, lat, lng)= self.cps[i]
-                slopelist.add_coord(slopenum, float(lat), float(lng))
+
+            for i in range(startindex, endindex):
+                dist = self.cps[i][0]
                 #create approximately N check points
-                if i == 0 or dist > next_cp or i == len(self.cps)-1:
-                    slopelist.add_cp(slopenum, dist, alt, name)
+                if i == startindex or dist > next_cp or i == endindex-1:
+                    self.cpToLoad.append(i)
                     next_cp = dist + max_dist/N
-            return True
         elif seltype == 1:#using the passed minimum distance in metres in num
             next_dist = num
-            for i in range(len(self.cps)):
-                (dist, alt, name, lat, lng)= self.cps[i]
-                slopelist.add_coord(slopenum, float(lat), float(lng))
-                if i == 0 or dist > next_dist or i == len(self.cps)-1:
-                    slopelist.add_cp(slopenum, dist, alt, name)
+            for i in range(startindex, endindex):
+                dist = self.cps[i][0]
+                if i == startindex or dist > next_dist or i == endindex-1:
+                    self.cpToLoad.append(i)
                     next_dist = dist + num
-            return True
-        else:
-            return False
-    def getCoords(self, slopelist, slopenum):
-        for i in range(len(self.cps)):
+        return True
+        
+    def getCoords(self, slopelist, slopenum, start_dist, end_dist):
+        """ Get coords from cps to the passed slope"""
+        startindex = 0
+        endindex = len(self.cps)
+        lencps = len(self.cps)
+
+        for i in range(lencps):
+            if self.cps[i][0] >= start_dist:
+                startindex = i
+                break
+        for i in range(lencps):
+            if self.cps[lencps-i-1][0] <= end_dist:
+                endindex = lencps - i
+                break
+
+        #print(startindex)
+        #print(endindex)
+        for i in range(startindex, endindex):
             (dist, alt, name, lat, lng)= self.cps[i]
             slopelist.add_coord(slopenum, float(lat), float(lng))
 
