@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """qt.gui.py"""
 
-# Copyright (C) 2009, 2010, 2011, 2012, 2013 Federico Brega, Pierluigi Villani
+# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014 Federico Brega, Pierluigi Villani
 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -115,7 +115,7 @@ CycloGraph is free software: you can redistribute it and/or modify it under the
 CycloGraph is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/.
 """
-        text = 'Copyright (C) 2008-2013 Federico Brega, Pierluigi Villani\n'+\
+        text = 'Copyright (C) 2008-2014 Federico Brega, Pierluigi Villani\n'+\
         'http://cyclograph.sourceforge.net\n'+ licence
         QtGui.QMessageBox.about(self, description +" "+ VERSION, text)
 
@@ -235,8 +235,6 @@ class Preferences(QtGui.QDialog, ui_qt.Ui_Pref_Dialog):
             self.serv.setCurrentIndex(2)
         elif pref['serv'] == 'earthtools.org':
             self.serv.setCurrentIndex(1)
-        elif pref['serv'] == 'google elevation':
-            self.serv.setCurrentIndex(3)
         #Fonts
         self.fontbuttonlist = [self.fdesc,
                                self.fgrad,
@@ -295,7 +293,7 @@ class Preferences(QtGui.QDialog, ui_qt.Ui_Pref_Dialog):
             self.olines.setChecked(bool(self.default['orizzontal lines']))
             self.showinfo.setChecked(bool(self.default['slopeinfo']))
             self.effect3d.setChecked(bool(self.default['effect-3d']))
-            self.vcheck.setChecked(bool(self.default['vcheck']))
+            self.vcheck.setChecked(bool(self.default['latestVersionCheck']))
             res = 0
             if self.default['width'] == 1600:
                 res = 3
@@ -312,8 +310,6 @@ class Preferences(QtGui.QDialog, ui_qt.Ui_Pref_Dialog):
                 self.serv.setCurrentIndex(2)
             elif self.default['server'] == 'earthtools.org':
                 self.serv.setCurrentIndex(1)
-            elif self.default['server'] == 'google elevation':
-                self.serv.setCurrentIndex(3)
 
             self.fdesc.setText(self.default['font-des 1']+' | '+self.default['font-dim 1'])
             self.fdesc.desc = {
@@ -640,6 +636,7 @@ class Create_kml(QtGui.QDialog, ui_qt.Ui_Create_KML_Dialog):
     """Create kml dialog"""
     MODE = {_("Open Route Service") : 'ORS',
             _(u'OSRM') : 'OSRM',
+            _(u'yournavigation') : 'YOURS',
             _("Draw on the map") : 'DRAW'}
 
     def __init__(self, parent, downloadfunc, savefunc):
@@ -663,6 +660,8 @@ class Create_kml(QtGui.QDialog, ui_qt.Ui_Create_KML_Dialog):
             self.webView.setUrl(QtCore.QUrl("http://openrouteservice.org/"))
         elif self.mode == 'OSRM':
             self.webView.setUrl(QtCore.QUrl("http://map.project-osrm.org/"))
+        elif self.mode == 'YOURS':
+            self.webView.setUrl(QtCore.QUrl("http://yournavigation.org/"))
         elif self.mode == 'DRAW':
             url = QtCore.QUrl("qrc:/openlayers/cyclograph/openlayers.html")#.fromLocalFile(os.path.join(os.path.dirname(__file__),"openlayers.html"))
             self.webView.setUrl(url)
@@ -705,6 +704,19 @@ class Create_kml(QtGui.QDialog, ui_qt.Ui_Create_KML_Dialog):
         url = gpxcontent.split('\'')
         return self.downloadfunc(url[1])
 
+    def get_yours(self):
+        """ Returns kml content from YOURS service"""
+        page = self.webView.page()
+        frame = page.currentFrame()
+
+        elemtext = unicode(frame.evaluateJavaScript("document.getElementById('feature_info').innerHTML").toString())
+        text = elemtext.split('href="http://yournavigation.org/?')
+        turl = "http://www.yournavigation.org/api/1.0/gosmore.php?format=kml&"
+        if len(text) > 1:
+            turl += text[1].split("\">")[0]
+            turl = turl.replace("&amp;", "&")
+        return self.downloadfunc(turl)
+
     def get_draw(self):
         frame = self.webView.page().currentFrame()
         kmlstring = frame.evaluateJavaScript("createKml()").toString()
@@ -715,6 +727,8 @@ class Create_kml(QtGui.QDialog, ui_qt.Ui_Create_KML_Dialog):
             self.handler = self.get_ors()
         elif self.mode == 'OSRM':
             self.handler = self.get_osrm()
+        elif self.mode == 'YOURS':
+            self.handler = self.get_yours()
         elif self.mode == 'DRAW':
             self.handler = self.get_draw()
 
@@ -730,19 +744,30 @@ class Create_kml(QtGui.QDialog, ui_qt.Ui_Create_KML_Dialog):
 
 class NumcpsDialog(QtGui.QDialog, ui_qt.Ui_numcps_dlg):
     """ask cps number you want to import"""
-    def __init__(self, max_num_cps, max_length, file_ext):
+    def __init__(self, max_num_cps, start_dist, finish_dist, file_ext):
         QtGui.QDialog.__init__(self, None)
         self.setupUi(self)
         self.slider.setMaximum(max_num_cps)
         self.spinBox.setMaximum(max_num_cps)
-        self.slider_2.setMaximum(int(max_length))
-        self.spinBox_2.setMaximum(int(max_length))
+        self.start.setRange(start_dist, finish_dist)
+        self.start.setValue(start_dist)
+        self.end.setRange(start_dist, finish_dist)
+        self.end.setValue(finish_dist)
+        selrange = self.end.value() - self.start.value()
+        #the value of the slider_2 is multiplied by 1000 to have a resolution of 0.001
+        self.slider_2.setMaximum(selrange*1000)
+        self.doubleSpinBox_2.setMaximum(selrange)
         text = _("The %s file contains %d points.\nChoose how many will be imported.") % (file_ext, max_num_cps)
         self.label.setText(text)
-        self.label_2.setText(_(u"The %s file contains a route of %d Km.\nChoose what range you want between points.") % (file_ext, max_length))
+        self.file_ext = file_ext
+        self.label_2.setText(_(u"The %s file contains a route of %.3f Km.\nChoose what range you want between points.") % (file_ext, finish_dist))
         self.label_3.setText(_("Choose the type of import you want"))
         
         self.proceedButton.clicked.connect(self.onProceedClicked)
+        self.start.valueChanged.connect(self.updateRange)
+        self.end.valueChanged.connect(self.updateRange)
+        self.slider_2.valueChanged.connect(self.updateSlider_2)
+        self.doubleSpinBox_2.valueChanged.connect(self.updateRange_2)
         
     def onProceedClicked(self):
         btn = self.buttonGroup.checkedButton()
@@ -752,6 +777,24 @@ class NumcpsDialog(QtGui.QDialog, ui_qt.Ui_numcps_dlg):
             self.stackedWidget.setCurrentIndex(1)
         elif btn == self.distance_2:
             self.stackedWidget.setCurrentIndex(2)
+            
+    def updateRange(self):
+        "The range changed"
+        self.start.setMaximum(self.end.value() - self.end.singleStep())
+        self.end.setMinimum(self.start.value() + self.start.singleStep())
+        self.slider_2.setMaximum((self.end.value() - self.start.value())*1000)
+        self.doubleSpinBox_2.setMaximum(self.end.value() - self.start.value())
+        
+    def updateRange_2(self):
+        "The range_2 changed"
+        spinval = self.doubleSpinBox_2.value()
+        self.slider_2.setValue(int(spinval*1000))
+
+    def updateSlider_2(self):
+        "The Slider_2 value changed"
+        sliderval = self.slider_2.value()/1000.0
+        self.doubleSpinBox_2.setValue(sliderval)
+        
 
 def preferences(parent, cgpref, defaultpref):
     """ set Preference dialog"""
@@ -786,19 +829,20 @@ def FileDialog(parent, title, dirname, filename, other,
     else:
         return None
 
-def numcpsdlg(max_num_cps, max_length, file_ext):
+def numcpsdlg(max_num_cps, start_dist, finish_dist, file_ext):
     """ask how many cps in a gpx or tcx files shall be imported"""
-    dlg = NumcpsDialog(max_num_cps, max_length, file_ext)
+    dlg = NumcpsDialog(max_num_cps, start_dist, finish_dist, file_ext)
     if dlg.exec_() == QtGui.QDialog.Rejected:
-        return (-1, 0)
+        return (-1, 0, start_dist, finish_dist)
     elif dlg.buttonGroup.checkedButton() == dlg.automatic:
-        return (0, -1)
+        return (0, -1, dlg.start.value(), dlg.end.value())
     elif dlg.buttonGroup.checkedButton() == dlg.all_:
-        return (0, 0)
+        return (0, max_num_cps, dlg.start.value(), dlg.end.value())
     elif dlg.stackedWidget.currentIndex() == 1:
-        return (0, dlg.slider.value())
+        return (0, dlg.slider.value(), dlg.start.value(), dlg.end.value())
     else:
-        return (1, dlg.slider_2.value())
+        value = dlg.doubleSpinBox_2.value()
+        return (1, value, dlg.start.value(), dlg.end.value())
 
 def geterrnoroute(parent):
     """Get an error message explaining that you should have selected one
