@@ -43,7 +43,7 @@ TEMPLATE_CSS = """
 """
 
 MAP_SCRIPT = """
-<script type="text/javascript" src="http://www.openlayers.org/dev/OpenLayers.js"></script>
+<script type="text/javascript" src="http://www.openlayers.org/api/OpenLayers.js"></script>
 <script type="text/javascript">
 
 vectorlayer = new OpenLayers.Layer.Vector("Vector Layer", {style: {strokeColor: "blue", strokeWidth: 5, strokeOpacity: 0.6}});
