@@ -34,6 +34,7 @@ class Slope:
         self.comment = ''
         self.url = ''
         self.reset_calculated()
+        
     def __len__(self):
         return len(self.cps)
         
@@ -62,17 +63,24 @@ class Slope:
         self.grad = []
         self.reset_calculated()
         return self.cps.index(new_cp)
+    
     def add_coord(self, latitude, longitude):
         """ Adds a coordinate to a Slope.
         A coordinate must have latitude and longitude.
         """
         new_coord = (latitude, longitude)
         self.coords.append(new_coord)
+        
     def remove_cp(self, num):
         """ Removes check-point num from current slope and clears data."""
         del self.cps[num]
         self.grad = []
         self.reset_calculated()
+        
+    def shift(self, shift_amount):
+        for i in range(len(self.cps)):
+            self.cps[i][0] += shift_amount
+            
     def calc(self):
         """ Update gradient and altitude bounds"""
         if len(self.cps) > 1:
@@ -423,10 +431,18 @@ class SlopeList:
             #if the slope isn't grown then a cp has been modified.
             self.message.send("SLOPE_DEL", slope_number, row_num)
         self.message.send("SLOPE_ADD", slope_number, row_num)
+        
     def remove_cp(self, slope_number, cp_num):
         """ Remove a check point from a slope in the list."""
         self._lst[slope_number].remove_cp(cp_num)
         self.message.send("SLOPE_DEL", slope_number, cp_num)
+        
+    def shift_slope(self, slope_number, shift_amount):
+        sel_lst = self._lst[slope_number]
+        sel_lst.shift(shift_amount)
+        for row_num in range(len(sel_lst)):
+            self.message.send("SLOPE_DEL", slope_number, row_num)
+            self.message.send("SLOPE_ADD", slope_number, row_num)
 
 
 
